# PiReplay

Python Package `pireplay` (managed using [Poetry](https://python-poetry.org/))

Capture and instantly replay the last moments using a Raspberry Pi and a camera with a WEB application.

**Note**: take a look at the project's GitHub repository **<https://github.com/gruvw/pireplay>**

## Installation

- Install by running: `pip install pireplay`
- Usage CLI: `pireplay --help`
